



python -c "import ctypes; ctypes.cdll[r'%PREFIX%\Library\bin\tbb.dll']"
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\include\\tbb\\tbb.h exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\lib\\tbb.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
exit 0
